Attributes

Struct Attributes 

pub struct Attributes(/* private fields */);
A collection of Attribute entries associated with an element.

Implementations

Source

impl Attributes

pub fn insert(&mut self, attribute: impl Into<Attribute>) -> Option<Attribute>

Available on crate feature write only.

Inserts the given attribute and returns the previous attribute with the same name, if any.

Examples
  • Inserting a custom attribute into a detached spine entry:
let mut detached = DetachedEpubSpineEntry::new("c1");
let mut entry_mut = detached.as_mut();
let attributes = entry_mut.attributes_mut();

// Insert a custom vendor attribute
attributes.insert(("this:appearance", "omit"));

assert_eq!(Some("omit"), attributes.get_value("this:appearance"));
pub fn by_name_mut(&mut self, name: &str) -> Option<&mut Attribute>

Available on crate feature write only.

Returns the mutable Attribute with the given name if present, otherwise None.

pub fn iter_mut(&mut self) -> AttributesIterMut<'_>

Available on crate feature write only.

Returns an iterator over all mutable Attribute entries.

pub fn remove(&mut self, name: &str) -> Option<Attribute>

Available on crate feature write only.

Removes and returns the attribute with the given name, if present.

pub fn retain(&mut self, f: impl FnMut(&Attribute) -> bool)

Available on crate feature write only.

Retains only the attributes specified by the predicate.

If the closure returns false, the attribute is retained. Otherwise, the attribute is removed.

This method operates in place and visits every attribute exactly once.

See Also
pub fn extract_if( &mut self, f: impl FnMut(&Attribute) -> bool, ) -> impl Iterator<Item = Attribute>

Available on crate feature write only.

Removes and returns only the attributes specified by the predicate.

If the closure returns true, the attribute is removed and yielded. Otherwise, the attribute is retained.

Drop

If the returned iterator is not exhausted, (e.g. dropped without iterating or iteration short-circuits), then the remaining attributes are retained.

Prefer Self::retain with a negated predicate if the returned iterator is not needed.

pub fn drain(&mut self) -> impl Iterator<Item = Attribute>

Available on crate feature write only.

Removes and returns all attributes.

pub fn clear(&mut self)

Available on crate feature write only.

Removes all attributes.

See Also
  • Self::drain to get an iterator of the removed attributes.
Source

impl Attributes

pub fn len(&self) -> usize

The number of Attribute entries contained within.

pub fn is_empty(&self) -> bool

Returns true if there are no attributes.

pub fn get(&self, index: usize) -> Option<&Attribute>

Returns the associated Attribute if the given index is less than Self::len, otherwise None.

pub fn iter(&self) -> AttributesIter<'_>

Returns an iterator over all Attribute entries.

pub fn by_name(&self, name: &str) -> Option<&Attribute>

Returns the Attribute with the given name if present, otherwise None.

See Also
pub fn get_value(&self, name: &str) -> Option<&str>

Returns the value of the Attribute with the given name if present, otherwise None.

pub fn has_name(&self, name: &str) -> bool

Returns true if an Attribute with the given name is present.