ResourceKey

Enum ResourceKey 

pub enum ResourceKey<'a> {
    Value(Cow<'a, str>),
    Position(usize),
}
A key identifying where the content is held for a Resource, either by string or numeric position.

Examples

  • Creating a key using From (Into is usable as well):
let position_key = ResourceKey::from(5);
let str_key = ResourceKey::from("OEBPS/nav/toc.xhtml");
// A path may be passed as well, although it must contain valid UTF-8.
// Otherwise, the requested file won't be found and an error will
// be propagated from methods that process a `ResourceKey`:
let str_key2 = ResourceKey::from(Path::new("EPUB/toc.ncx"));

assert!(matches!(position_key, ResourceKey::Position(5)));
assert!(matches!(str_key, ResourceKey::Value(Cow::Borrowed("OEBPS/nav/toc.xhtml"))));
assert!(matches!(str_key2, ResourceKey::Value(Cow::Borrowed("EPUB/toc.ncx"))));

Variants



Value(Cow<'a, str>)

A string-based key (e.g., file path, URI) that references where a resource is stored.

When using the From<&Path> impl, the input must be valid UTF-8; any non-UTF-8 sequences will be replaced with .



Position(usize)

A numeric index-based key for locations that cannot be represented with a string value.

This is primarily useful for resources that do not have a string value available, but rather a “pointer” to access an element within an indexable structure, such as the MOBI format.

Implementations

Source

impl ResourceKey<'_>

pub fn value(&self) -> Option<&str>

Returns the contained value if self is ResourceKey::Value.

Examples
  • Retrieving the value:
let key = ResourceKey::from("value");
assert_eq!(Some("value"), key.value());
assert_eq!(None, key.position());
pub fn position(&self) -> Option<usize>

Returns the contained position if self is ResourceKey::Position.

Examples
  • Retrieving the position:
let key = ResourceKey::from(5);
assert_eq!(Some(5), key.position());
assert_eq!(None, key.value());