ReaderKey

Enum ReaderKey 

#[non_exhaustive]
pub enum ReaderKey<'a> { Value(&'a str), Position(usize), }
A key to access content within a Reader.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Value(&'a str)

A string value, intended for lookup within a Reader.

For an Epub, this value corresponds to the idref of a spine entry.



Position(usize)

An absolute position within the internal buffer of a Reader.

When passed as an argument to a reader, it must be less than Reader::len or ReaderError::OutOfBounds will be returned.